# frozen_string_literal: true

require 'puppet/type/db2_instance'

Facter.add('db2_instances') do
  confine do
    Puppet.features.db2_running?
  end

  def db2version(instance)
    Facter::Util::Resolution.exec("su - #{instance} -c 'db2level'") || ''
  end

  setcode do
    Puppet::Type::Db2_instance::ProviderDb2.instances.reduce({}) do |value, data|
      selection = [:authentication, :dftdbpath, :comm_exit_list, :python_path, :r_path, :jdk_path, :alt_diagpath, :diagpath, :jdk_path, :state, :sysadm_group, :version, :logarchmeth1, :sysadm_group, :sysctrl_group, :sysmaint_group, :sysmon_group]
      data = data.to_hash
      name = data[:name]
      data[:version] = db2version(name).scan(/DB2 v(.*?)"/).flatten.first
      data = data.select { |k, _v| selection.include?(k) }
      value.merge(name => data)
    end
  end
end
