# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:statement) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Access
  include EasyType::Helpers

  desc <<-DESC
    The sql command to execute.

    This is a required string value. The value must either contain a valid SQL statement:

        db2_exec { 'select * from tab@sid':
        }

    or a valid script name.

        db2_exec { '@/tmp/valid_sql_script.sql@sid':
        }

    when you don't specify a directory, Puppet will use the default directory specified in the
    `cwd` parameter.

        db2_exec { '@valid_sql_script.sql@sid':
          ...
          cwd => '/tmp',
        }

  DESC

  #
  # Let the insync? check for the parameter unless and the refreshonly
  #
  def insync?(_to)
    if resource[:refreshonly].to_s == 'true'
      true
    else
      !provider.need_to_execute?
    end
  end

  data_type('Variant[Sensitive,String[1]]')
end
