# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newparam(:unless) do
  include EasyType
  desc <<-DESC
    A query to determine if the db2_exec must execute or not.

    If the query returns something, either one or more rows, the db2_exec
    is **NOT** executed. If the query returns no rows, the specified db2_exec
    statement **IS** executed.

    The `unless` clause **must** be a valid query. An error in the query will result in
    a failure of the apply statement.

    If you have specified a username and a password, the `unless` statement will be
    executed in that context. E.g. logged in as the specified user with the specified
    password.

    The default value is empty. Meaning no `unless` statement is executed and the statement or script
    specified in the title, will always be executed.

        db2_exec{ "create synonym ${user}.${synonym} for PRES.${synonym}":
          unless  => "select * from all_synonyms where owner=\'${user}\' and synonym_name=\'${synonym}\'",
        }

  DESC
  data_type('Optional[Variant[String[1],Integer]]')
end
