# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:db2_group) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type
  include PuppetX::EnterpriseModules::Db2::Access

  desc <<-DESC
  This resource allows you to manage a DB2 group. Here is an example on how to use this:

      db2_group { 'db2inst1/MYDB/PUBLIC':
        ensure   => 'present',
        grants   => ['BINDADD', 'CONNECT', 'CREATETAB', 'IMPLICIT_SCHEMA'],
        provider => 'db2',
        roles    => ['SYSTS_USR'],
      }

  Puppet will **NOT** create the OS groups, but it will manage grants and roles.


  DESC

  to_get_raw_resources do
    groups = []
    db2_instance_names.each do |instance|
      primary_database_names_on(instance).each do |database|
        groups += groups_on(instance, database).collect { |e| e.merge(:instance => instance, :database => database) }
      end
    end
    groups
  end

  ensurable

  on_create do
    db2 "grant dbadm, createtab, bindadd, connect, create_not_fenced, implicit_schema, load on database to group #{group_name}", :instance => instance_name, :database => database_name
    nil
  end

  on_modify do
    # The properties take care of this
  end

  on_destroy do
    db2 "revoke #{provider.grants.join(',')} on database from group #{group_name}", :instance => instance_name, :database => database_name
    nil
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :group_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :group_name

  property  :grants
  property  :granted
  property  :revoked
  property  :roles
end
