# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newparam(:grantee) do
  include EasyType
  include EasyType::Validators::Name

  desc <<-DESC
    The DB2 username that is granted (or revoked) the permission.

    This parameter is extracted from the title of the type. It is separated by the object by a `/`.

        db2_object_grant { 'SCOTT->sys.dbms_aqin@SID':
          ...
        }

    In this example `SCOTT` is the grantee. Grantee names will always be uppercased by Puppet.
    This means in Puppet you can use either lower, upper or mixed case. In DB2, it will be always be an upper
    case string.

  DESC

  isnamevar
  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('GRANTEE').upcase
  end
end
