# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newparam(:name) do
  include EasyType
  include EasyType::Validators::Name

  desc <<-DESC
    The object and name combination you want to manage. Including an appended SID.

        db2_object_grant { 'db2inst1/MYDB/SCOTT->sys.dbms_aqin':
          ...
        }

  DESC

  isnamevar
  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    instance    = raw_resource.column_data(:instance)
    database    = raw_resource.column_data(:database)
    granteetype = raw_resource.column_data('GRANTEETYPE').strip.upcase
    grantee     = raw_resource.column_data('GRANTEE').strip.upcase
    schema      = raw_resource.column_data('TABSCHEMA').strip.upcase
    table_name  = raw_resource.column_data('TABNAME').strip.upcase
    # rubocop: disable Style/HashLikeCase
    type = case granteetype
           when 'G'
             'GROUP'
           when 'R'
             'ROLE'
           when 'U'
             'USER'
           end
    # rubocop: enable Style/HashLikeCase
    "#{instance}/#{database}/#{type}/#{grantee}->#{schema}.#{table_name}"
  end
end
