# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newparam(:object_name) do
  include EasyType
  include EasyType::Validators::Name

  desc <<-DESC
    The object name.

    This parameter is extracted from the title of the type. It is the first part of the name.

        db2_object_grant { 'SCOTT->sys.dbms_aqin@SID':
          ...
        }

    In this example `sys.dbms_aqin` is the object name. The object names will always be uppercased by Puppet.
    This means in Puppet you can use either lower, upper or mixed case. In DB2, it will be always be an upper
    case string.

    You must specify full qualified object names. This means `owner.object`.

    The table may be a valid sql wildcard like `DBA_%`. Here is an example of such a resource definition:

        db2_object_grant { 'APPQOSSYS->SYS.DBA_%@TEST':
          permissions => [],
        }

    This wil revoke all rights on all DBA tables from user `APPQOSSYS`.

  DESC

  isnamevar
  data_type('String[1]')
end
