# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:db2_role) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type
  include PuppetX::EnterpriseModules::Db2::Access

  desc <<-DESC

    This resource allows you to manage a DB2 role. Here is an example on how to use this:

        db2_role { 'db2inst1/MYDB/MY_ROLE':
          ensure   => 'present',
          grants   => ['DBADM', 'SECADM', 'ACCESSCTRL'],
          provider => 'db2',
          roles    => ['SYSTS_ADM', 'SYSTS_MGR', 'SYSDEBUG', 'SYSDEBUGPRIVATE'],
        }

  DESC

  to_get_raw_resources do
    roles = []
    db2_instance_names.each do |instance|
      primary_database_names_on(instance).each do |database|
        roles += roles_on(instance, database).collect { |e| e.merge(:instance => instance, :database => database) }
      end
    end
    roles
  end

  ensurable

  on_create do
    db2 "create role #{role_name}", :instance => instance_name, :database => database_name
    nil
  end

  on_modify do
    # The properties take care of this
  end

  on_destroy do
    db2 "drop role #{role_name}", :instance => instance_name, :database => database_name
    nil
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :role_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :role_name

  property  :grants
  property  :granted
  property  :revoked
  property  :roles
  property  :remarks
end
