# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:parameters) do
  include EasyType

  desc <<-DESC
    The parameters to pass to the sql upgrade and downgrade scripts.

    Sometimes you want to parameterize the upgrade end/or downgrade SQL-scripts. This is supported by the `parameters` property. Here is an example of a definition.

        db2_schema_definition{ 'db2inst1/MYDB/MYAPP':
            ensure      => 'latest',
            schema_name => 'MYAPP,
            password    => 'verysecret',
            source_path => '/opt/stage/myapp/sql',
            parameters  => {
              myapp_data_tablespace => 'MYAPP_DATA',
              myapp_idx_tablespace  => 'MYAPP_DATA',
            }
        }

    In the SQL-scripts you can use these parameters like this:

        CREATE TABLE order(
        ...
        ) TABLESPACE &myapp_data_tablespace


  DESC

  # rubocop: disable Lint/EmptyBlock
  defaultto {}
  # rubocop: enable Lint/EmptyBlock
  data_type('Optional[Hash]')
end
