# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newparam(:schema_name) do
  include EasyType
  include EasyType::Validators::Name

  isnamevar

  desc <<-DESC
    The schema name.

    The schema name is part of the title of the resource. In this example:

        db2_schema_definition{'db2inst1/MYDB/MYAPP':
          ensure => latest,
          password => 'secret',
          ...
        }

    The schema name is the last part of the title after all the '/'. In this case `MYAPP`.
    The puppet type uses this as the Db2 user to log in. Yo must specify the password in the
    resource definition.

  DESC

  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('APPLICATION').upcase
  end
end
