# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:pcmkr_cluster) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type

  def self.module_name
    'db2_config'
  end

  desc <<-DESC
  This resource allows you to manage an Pacemaker cluster. Here is an example on how to use this:

      pcmkr_cluster { 'cluster':
        ensure     => 'present',
        interfaces => ['eth0', 'eth0'],
        nodes      => ['db1157a', 'db1157b'],
      }

  All of these properties are read-only. If you need to add nodes, or change interfaces, the cluster
  must be recreated. At this point in time Puppet does not take care of this.

  DESC

  to_get_raw_resources do
    pcmkr_clusters
  end

  ensurable

  on_create do
    hosts_part = []
    nodes.each_with_index { |n, i| hosts_part << "-host #{n} -publicEthernet #{interfaces[i]}" }
    Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -create -cluster -domain #{name} #{hosts_part.join(' ')}")
    nil
  end

  on_modify do
    fail 'At this point in time Pacemaker does not support modifying clusters.'
  end

  on_destroy do
    Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -delete -cluster")
  end

  parameter :name
  parameter :location

  property :version
  property :leader
  property :nodes
  property :interfaces
end
