# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:pcmkr_instance) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type

  def self.module_name
    'db2_config'
  end

  desc <<-DESC
  This resource allows you to manage an Pacemaker instance. Here is an example on how to use this:

      pcmkr_instance { 'db2inst1':
        ensure     => 'present',
        nodes      => ['db1157a', 'db1157b'],
      }

  All of these properties are read-only. If you need to add nodes, or change interfaces, the resource
  must be recreated. At this point in time Puppet does not take care of this.

  DESC

  to_get_raw_resources do
    pcmkr_instances
  end

  ensurable

  on_create do
    nodes.each do |node|
      Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -create -instance #{name} -host #{node}")
    end
    nil
  end

  on_modify do
    fail 'At this point in time Pacemaker does not support modifying instances.'
  end

  on_destroy do
    provider.nodes.each do |node|
      Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -delete -instance #{name} -host #{node}")
    end
    nil
  end

  parameter :name
  parameter :location

  property :nodes
  property :state
  property :managed
end
