# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:pcmkr_qdevice) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type

  def self.module_name
    'db2_config'
  end

  desc <<-DESC
  This resource allows you to manage an Pacemaker qdevice. Here is an example on how to use this:

      pcmkr_qdevice { 'db1157c':
        ensure     => 'present',
      }


  DESC

  to_get_raw_resources do
    pcmkr_qdevices
  end

  ensurable

  on_create do
    Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -create -qdevice #{name}")
  end

  on_modify do
    fail 'At this point in time Pacemaker does not support modifying qdevice resources.'
  end

  on_destroy do
    Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -delete -qdevice")
  end

  parameter :name
  parameter :location
end
