# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:pcmkr_vip) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type

  def self.module_name
    'db2_config'
  end

  desc <<-DESC
  This resource allows you to manage an Pacemaker VIP. Here is an example on how to use this:

      pcmkr_vip { 'db2inst1/MYDB/primary/10.20.21.4':
        ensure     => 'present',
      }

  DESC

  to_get_raw_resources do
    pcmkr_vips
  end

  ensurable

  on_create do
    Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -create -#{self[:type]}VIP #{address} -db #{database_name} -instance #{instance_name}")
  end

  on_modify do
    fail 'At this point in time Pacemaker does not support modifying VIPS.'
  end

  on_destroy do
    Puppet.debug Puppet::Util::Execution.execute("#{location}/bin/db2cm -delete -#{self[:type]}VIP -db #{database_name} -instance #{instance_name}")
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :type, :address]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :address
  parameter :location
  parameter :type

  property :managed
  property :state
end
