# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/db2/core'

module PuppetX
  module EnterpriseModules
    module Db2
      # docs
      class Db2cmParser
        include Singleton

        def initialize
          location = db2_locations.first
          @raw_output = Puppet::Util::Execution.execute("#{location}/bin/db2cm -list", :failonfail => false)
        end

        def db2ls
          @db2ls ||= Puppet::Util::Execution.execute('/usr/local/bin/db2ls -c') || ''
        end

        def db2_locations
          data_lines = db2ls.split("\n").drop(1)
          data_lines.collect do |line|
            line.split(':')[0]
          end
        end

        def nodes
          return [] if @raw_output.to_s.include?('There is no cluster on this host')

          node_text = @raw_output.split('Resource Information:').first
          node_text.scan(/^(\S+)\s+(?:Online|Offline)$/).flatten
        end

        def interfaces(nodes)
          return [] if @raw_output.to_s.include?('There is no cluster on this host')

          raw_text = @raw_output.split(/^ $/).drop(1)
          raw_info = raw_text.collect do |resource|
            EasyType::Helpers::InstancesResults[resource.scan(/\s+(.+?)\s+=\s+(\S+)/)]
          end
          raw_info.each_with_object([]) do |element, acc|
            nodes.each do |node|
              next unless element['Resource Type'] == 'Network' && element['Node'] == node

              acc << element['Interface Name']
            end
          end
        end

        def instances
          return [] if @raw_output.to_s.include?('There is no cluster on this host')

          raw_text = @raw_output.split(/^ $/).drop(1)
          raw_info = raw_text.collect do |resource|
            EasyType::Helpers::InstancesResults[resource.scan(/\s+(.+?)\s+=\s+(\S+)/)]
          end
          #
          # Convert to array of Instances with node info
          #
          raw_info.each_with_object([]) do |element, acc|
            next unless element['Resource Type'] == 'Instance'
            next acc if acc.find { |e| e['Name'] == element['Name'] }

            element['Nodes'] = nodes
            element['Interfaces'] = interfaces(nodes)
            acc << element
          end
        end

        def databases
          return [] if @raw_output.to_s.include?('There is no cluster on this host')

          raw_text = @raw_output.split(/^ $/)
          raw_info = raw_text.collect do |resource|
            EasyType::Helpers::InstancesResults[resource.scan(/\s+(.+?)\s+=\s+(\S+)/)]
          end
          #
          # Convert to array of database
          #
          raw_info.each_with_object([]) do |element, acc|
            acc << element if element['Resource Type'] == 'HADR'
          end
        end

        def vips
          return [] if @raw_output.to_s.include?('There is no cluster on this host')

          raw_text = @raw_output.split(/^ $/)
          raw_info = raw_text.collect do |resource|
            EasyType::Helpers::InstancesResults[resource.scan(/\s+(.+?)\s+=\s+(\S+)/)]
          end
          #
          # Convert to array of database
          #
          raw_info.each_with_object([]) do |element, acc|
            acc << element if element['Resource Type'] == 'IP'
          end
        end

        def qdevices
          return [] if @raw_output.to_s.include?('There is no cluster on this host')

          name = @raw_output.scan(/QNetd host:\s+(\S+):/).flatten
          name.empty? ? [] : [{ :name => name.first }]
        end

        def clusters
          return [] if @raw_output.to_s.include?('There is no cluster on this host')

          raw_text = @raw_output.split(/^ $/)
          raw_info = raw_text.collect do |resource|
            EasyType::Helpers::InstancesResults[resource.scan(/\s+(.+?)\s+=\s+(\S+)/)]
          end

          #
          # Convert to array of Instances with node info
          #
          raw_info.each_with_object([]) do |element, acc|
            next unless element['Domain name']

            element['nodes'] = nodes
            element['Interfaces'] = interfaces(nodes)
            acc << element
          end
        end
      end
    end
  end
end
