# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/db2/command'
require 'tmpdir'

module PuppetX
  module EnterpriseModules
    module Db2
      # docs
      class Db2pdCommand < PuppetX::EnterpriseModules::Db2::Command
        include EasyType::Template

        DB2PD_VALID_OPTIONS ||= [
          :instance,
          :timeout,
          :failonfail
        ].freeze

        def initialize(options = {})
          super(:db2pd, options, DB2PD_VALID_OPTIONS)
          @failonfail = options.fetch(:failonfail, true)
        end

        def execute(arguments)
          options = { :failonfail => @failonfail, :combine => true }
          value = ''
          within_time(@timeout) do
            value = execute_on_instance(arguments, options)
          end
          value
        end

        def execute_on_instance(arguments, options)
          Puppet.debug "db2pd_command.rb: Executing #{@command} command: #{arguments} on #{@instance}, connected as #{@username}"
          # rubocop: disable Style/GuardClause
          if Puppet::Util::Platform.windows?
            fail 'No windows support yet'
          else
            Puppet::Util::Execution.execute(command_string(arguments), options)
          end
          # rubocop: enable Style/GuardClause
        end
      end
    end
  end
end
