#
# db2_config::clear_caches
#
# @summary This class contains the puppet code that implements the default facter cache invalidation rules.
# Whenever a certain set of Puppet classes or defined types is applied, it will clear the facter caches for those facts that are implemented.
#
#
# See the file "LICENSE" for the full license governing this code.
#
class db2_config::clear_caches () {
  fact_cache { 'db2_databases':
    ensure      => absent,
    refreshonly => true,
  }
  Db2_database<||> ~> Fact_cache['db2_databases']

  fact_cache { 'db2_instances':
    ensure      => absent,
    refreshonly => true,
  }
  Db2_instance<||> ~> Fact_cache['db2_instances']

  fact_cache { 'db2_tablespaces':
    ensure      => absent,
    refreshonly => true,
  }
  Db2_schema<||> ~> Fact_cache['db2_schemas']

  fact_cache { 'db2_version':
    ensure      => absent,
    refreshonly => true,
  }
  if defined('Db2_install::Software') {
    Db2_install::Software<||> ~> Fact_cache['db2_version']
  }
}
